<?php
$page_title = "User Details";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href="account_list"><img src="../img/logo.png" alt="iWallet"></a></h1>
				<form id="searchForm" action="" method="post">
					<input type="hidden" id="detail_account" name="detail_account" value="<?php $this -> echoAccountNumber(); ?>">
					<div class="aside-heading">
						<div class="btns">
							<input type="button" id="btnSeeTransactions" value="See Transactions" class="btn bg-default px120 hi22">&nbsp;
						</div>
					</div>
					<input type="hidden" value="" id="s_type" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>Affiliated WL</th>
									<td><?php $this -> echoWLName(); ?></td>
								</tr>
								<tr>
									<th>Username</th>
									<td><?php $this -> echoUserName(); ?></td>
								</tr>
								<tr>
									<th>Account Number</th>
									<td><?php $this -> echoAccountNumber(); ?></td>
								</tr>
								<tr>
									<th>Currencies</th>
									<td>
										<ul class="disc">
											<?php $this -> dispBalances(); ?>
										</ul>
									</td>
								</tr>
								<tr>
									<th>Name</th>
									<td><?php $this -> echoLastName(); ?>&nbsp;<?php $this -> echoFirstName(); ?></td>
								</tr>
								<tr>
									<th>Date of Birth</th>
									<td><?php $this -> echoBirth(); ?></td>
								</tr>
								<tr>
									<th>Date of Registration</th>
									<td><?php $this -> echoCreateTime(); ?></td>
								</tr>
								<tr>
									<th>Account Type</th>
									<td><?php $this -> echoAccountType(); ?></td>
								</tr>
								<tr>
									<th>Account Category</th>
									<td><?php $this -> echoTestAccountFlg(); ?></td>
								</tr>
								<tr>
									<th>CRM ID</th>
									<td><?php $this -> echoCrmId(); ?></td>
								</tr>
								<tr>
									<th>KYC Status</th>
									<td><?php $this -> dispKYCFlg(); ?></td>
								</tr>
								<tr>
									<th>Account Status</th>
									<td><?php $this -> dispStatus(); ?></td>
								</tr>
								<tr>
									<th>Country</th>
									<td><?php $this -> echoCountry(); ?></td>
								</tr>
								<tr>
									<th>State</th>
									<td><?php $this -> echoState(); ?></td>
								</tr>
								<tr>
									<th>City</th>
									<td><?php $this -> echoCity(); ?></td>
								</tr>
								<tr>
									<th>Address</th>
									<td><?php $this -> echoAddress() . '&nbsp;' . $this -> echoAddress2(); ?></td>
								</tr>
								<tr>
									<th>Post Code</th>
									<td><?php $this -> echoZipCode(); ?></td>
								</tr>
								<tr>
									<th>Phone Number</th>
									<td><?php $this -> echoTel(); ?></td>
								</tr>
								<tr>
									<th>Email Address</th>
									<td><?php $this -> echoMail(); ?></td>
								</tr>
								<tr>
									<th>Agent Code</th>
									<td><?php $this -> echoAgentCode(); ?></td>
								</tr>
								<?php $this -> echo2facontrol(); ?>
								<tr>
									<th>Login Lock</th>
									<td><?php $this -> dispLoginLock(); ?></td>
								</tr>
								<tr>
									<th>KYC Confirmation Documents</th>
									<td><a href="#" id="btnRollBack">Return KYC Confirmation</a>　　　　<input id="kycUpload" value="File Upload" class="btn bg-grad hi25" style="width:150px;"type="button"></td>
								</tr>
								<?php $this -> reSendLink(); ?>
								<tr>
									<th>Batch Transfer</th>
									<td><?php $this -> echoTransferBatchFlg(); ?></td>
								</tr>
								<tr>
									<th>Card Registration</th>
									<td>
										<ul class="disc">
											<?php $this -> dispCards(); ?>
											<?php $this -> dispMsg(); ?>
										</ul>
										<br/>
										Card Holder ID：<input type="text" value="<?php $this -> echoCardHolderId(); ?>" id="card_holder_id" name="card_holder_id" class="w20p" /><br/>
										Card Number：<input type="text" value="<?php $this -> echoDigit(); ?>" id="card_number" name="card_number" class="w20p" /><br/>
										Proxy：<input type="text" value="<?php $this -> echoDigit(); ?>" id="proxy" name="proxy" class="w20p" /><br/>
										Expiration Date：<input type="text" value="<?php $this -> echoDigit(); ?>" id="expire_date" name="expire_date" class="w20p" /><br/>
										<input type="button" id="btnRegistCard" value="Register" class="btn bg-grad px80 hi25">
									</td>
								</tr>
	<!-- Mikko 2019 -->
								<tr>
									<th>Risk Level</th>
									<td>
										<?php $this -> echoRiskLevel(); ?>
									</td>
								</tr>
								<tr>
									<th>Tier Level</th>
									<td>
										<?php $this -> echoTierLevel(); ?>
									</td>
								</tr>
								<tr>
									<th>Related Accounts</th>
									<td>
										<ul class="disc">
											<?php $this -> dispUserLink(); ?>
											<?php $this -> dispMsg2(); ?>
										</ul>
										<br/>
										<fieldset id="fields">
											<div class="fieldwrapper" id="field0">
												Account Number：<input type="text" value="<?php //$this -> echoUserLink(); ?>" id="link_user" name="link_user[]" class="w20p" />
												 <input type ="button" value="+" id="addField" name="addField" class="btn bg-grad px40 addField" />
											</div>
										</fieldset>
										<input type="button" id="btnLinkUser" value="Register" class="btn bg-grad px80 hi25">
									</td>
								</tr>
								<!-- Mikko 2019 -->
								<tr>
									<th>Potential Duplicate</th>
									<td><a href="account_duplicate_com?user_account=<?php $this -> echoAccountNumber(); ?>"><?php $this -> echoMail(); ?></a> </td>
								</tr>
								<tr>
									<th>Receive User-Initiated Internal Transfer</th>
									<td><?php $this -> echoTransferFlg(); ?></td>
								</tr>
							</table>

							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>GPaySafe Deposit Methods</th>
									<td><?php $this -> echoGpsKindOfPayments(); ?></td>
								</tr>
								<tr>
									<th>GPaySafe Account Type</th>
									<td><?php $this -> echoGPSAccountFlg(); ?></td>
								</tr>
							</table>

							<?php $this -> dispCorporation(); ?>
							<p class="calign mb20">
								<input type="button" id="btnInput" value="Edit" class="btn bg-grad px80 hi25">
							</p>
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>Payment Solution Custom Access</th>
									<td>
										<div><label class="method_name"><b>Deposit Method</b></label></div><div><?php $this -> echoUserCustomAccess(PARAM_DEPOSIT); ?></div>

										<div><label class="method_name"><b>Withdrawal Method</b></label></div><div><?php $this -> echoUserCustomAccess(PARAM_WITHDRAW); ?></div>
									</td>
								</tr>
							</table>
							<p class="calign mb20">
								<input type="button" id="btnInputPaymentAccess" value="Edit" class="btn bg-grad px80 hi25">
							</p>
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<tr>
									<th>
										Remarks&emsp;
										<input type="button" id="btnSave" value="Save" class="btn bg-default font12 hi22 px80">
									</th>
								</tr>
								<tr>
									<td>
										<textarea rows="10" id="note" name="note" class="w100p"><?php $this -> echoNote(); ?></textarea>
									</td>
								</tr>
							</table>
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<tr>
									<th>
										Risk Remark&emsp;
										<input type="button" id="btnSaveRisk" value="Save" class="btn bg-default font12 hi22 px80">
									</th>
								</tr>
								<tr>
									<td>
										<textarea rows="10" id="risk" name="risk" class="w100p"><?php $this -> echoRisk(); ?></textarea>
									</td>
								</tr>
							</table>
							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" value="<?php $this -> echoReferer(); ?>" id="action" name="action" />
							<input type="hidden" value="<?php echo $this -> getDetailAccount(); ?>" name="detail_account" />
							<input type="hidden" value="" id="c_id" name="c_id" />
							<input type="hidden" value="" id="l_id" name="l_id" />

							<!-- Language Transition Data (Anton) 04/22/2016 -->
							<input class="lang-trans-data" type="hidden" id="lang_data_action" value="/account_edit?detail_account=<?php $this -> echoAccountNumber(); ?>"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_type" value="action"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_form" value="#acForm"/>
							<!-- /Language Transition Data -->
						</form>
						<p class="calign mb20">
							<a href="javascript:actionBack();" class="btn bg-default">&laquo; Back</a>
						</p>
						
						<div class="article-bottom">
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/account_edit.js"></script>
    <script src="../js/bootstrap.min.js"></script>
</body>
</html>
